function back = haarit(trans)
%
% haarit: inverse image from the haar transformed coefficients
% On input:
%     trans: Haar transform coeeficients 
% On output:
%     back: reconstructed image
% Call:
%     back = haarit(trans)
%

[m,n] = size(trans);

H = haar(m);

back = H'*trans*H';



